<html>
<head><title>ownCloud Package Removed from Ubuntu</title></head>
<body>
<h1>ownCloud Package Removed</h1>

<p> The ownCloud package has been removed from Ubuntu due to security issues that
 can not easily be updated.</p>


<p> Alternative ways to install are:</p>
<ul>
<li>Using the ownCloud packages on OBS:
  <a href="http://software.opensuse.org/download/package?project=isv:ownCloud:community&package=owncloud">http://software.opensuse.org/download/package?project=isv:ownCloud:community&package=owncloud</a>
</li>
<li>The Juju ownCloud charm:
  <a href="https://jujucharms.com/precise/owncloud/">https://jujucharms.com/precise/owncloud/</a></li>
</ul>

</body>
</html>
